from setuptools import setup

setup(
    name='elibs',
    version='1.1.2',
    packages=['elibs', 'elibs.utils', 'elibs.tom_ticket', 'elibs.tom_ticket.models'],
    url='',
    license='',
    author='ellitedev',
    author_email='osni@sotech.xyz',
    description='Biblioteca de integração com o TomTicket'
)
